You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by ja...@apache.org on 2017/03/16 12:10:21 UTC

[2/3] cassandra git commit: Support unaligned memory access for AArch64

Support unaligned memory access for AArch64

patch by yuqi, reviewed by jasobrown for CASSANDRA-13326


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/6e76bbb3
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/6e76bbb3
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/6e76bbb3

Branch: refs/heads/trunk
Commit: 6e76bbb3faeb91c953cb7717dbc39105eed22da9
Parents: a2399d4
Author: yuqilinaro <yu...@linaro.org>
Authored: Wed Mar 15 07:06:33 2017 +0000
Committer: Jason Brown <ja...@gmail.com>
Committed: Thu Mar 16 05:08:01 2017 -0700

----------------------------------------------------------------------
 CHANGES.txt                                           | 1 +
 src/java/org/apache/cassandra/utils/Architecture.java | 7 ++++---
 2 files changed, 5 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index ab28dd4..6d2e6c6 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,4 +1,5 @@
 3.11.0
+ * Support unaligned memory access for AArch64 (CASSANDRA-13326)
  * Improve SASI range iterator efficiency on intersection with an empty range (CASSANDRA-12915).
  * Fix equality comparisons of columns using the duration type (CASSANDRA-13174)
  * Obfuscate password in stress-graphs (CASSANDRA-12233)

http://git-wip-us.apache.org/repos/asf/cassandra/blob/6e76bbb3/src/java/org/apache/cassandra/utils/Architecture.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/utils/Architecture.java b/src/java/org/apache/cassandra/utils/Architecture.java
index c18185a..aa00ca1 100644
--- a/src/java/org/apache/cassandra/utils/Architecture.java
+++ b/src/java/org/apache/cassandra/utils/Architecture.java
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 
 public final class Architecture
 {
     // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
     // for those that want to run C* on this architecture at their own risk (see #11214)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",
         "x86",
         "amd64",
         "x86_64",
-        "s390x"
+        "s390x",
+        "aarch64"
     ));
 
     public static final boolean IS_UNALIGNED = UNALIGNED_ARCH.contains(System.getProperty("os.arch"));
@@ -26,14 +26,15 @@ import com.google.common.collect.Sets;
 public final class Architecture
 {
-    // Note that s390x architecture are not officially supported and adding it here is only done out of convenience
-    // for those that want to run C* on this architecture at their own risk (see #11214)
+    // Note that s390x & aarch64 architecture are not officially supported and adding it here is only done out of convenience
+    // for those that want to run C* on this architecture at their own risk (see #11214 & #13326)
     private static final Set<String> UNALIGNED_ARCH = Collections.unmodifiableSet(Sets.newHashSet(
         "i386",